@@ -281,3 +281,145 @@ sub render_something_with_email_addr
 }
 
 1;
+
+__END__
+=head1 NAME
+
+Mail::LMLM::Types::Base - the base class for the mailing list types.
+
+=head1 SYNOPSIS
+
+Extend the class.
+
+=head1 METHODS
+
+=head2 Mail::LMLM::Types::MyMailingListType->new(%args)
+
+%args keys can be:
+
+=over 4
+
+=item * id
+
+The id of the mailing list - used for URLs, etc.
+
+=item * group_base
+
+The base username of the mailing list.
+
+=item * desc (or description)
+
+The description of the mailing list.
+
+=item * hostname
+
+The hostname where the mailing list is hosted.
+
+=item * homepage
+
+The mailing list's homepage
+
+=item * online_archive
+
+The online archive of the mailing list (can be a coderef).
+
+=item * guidelines
+
+Guidelines for posting on the list.
+
+=item * notes
+
+Notes for the mailing list.
+
+=back
+
+=head2 get_id()
+
+An accessor for the ID.
+
+=head2 get_description()
+
+An accessor for the description.
+
+=head2 get_homepage
+
+An accessor for the homepage. (may be overrided by derived classes).
+
+=head2 get_group_base
+
+An accessor for the group base.
+
+=head2 get_hostname
+
+An accessor for the hostname.
+
+=head2 get_online_archive
+
+An accessor for the online archive.
+
+=head2 get_guidelines
+
+An accessor for the guidelines.
+
+=head2 render_subscribe
+
+Render the subscribe part.
+
+=head2 render_unsubscribe
+
+Render the unsubscribe part.
+
+=head2 render_post
+
+Render the post part.
+
+=head2 render_owner
+
+Render the owner part.
+
+=head2 render_none
+
+Render a paragraph saying "None".
+
+=head2 render_homepage
+
+Render the homepage part.
+
+=head2 render_online_archive
+
+Render the online archive part.
+
+=head2 $self->render_field($htmler, $desc)
+
+Renders the $desc using the rendered.
+
+=head2 render_description
+
+Render the description part.
+
+=head2 render_guidelines
+
+Render the guidelines part.
+
+=head2 $type->render_something_with_email_addr($htmler, $begin_msg, $address_method)
+
+Render something with the email address.
+
+=head1 INTERNAL METHODS
+
+=head2 initialize()
+
+This is a helper for new(). For internal use.
+
+=head2 parse_args()
+
+This is a helper for initialize(). For internal use.
+
+=head1 SEE ALSO
+
+L<Mail::LMLM>
+
+=head1 AUTHOR
+
+Shlomi Fish, L<http://www.shlomifish.org/>
+
